Discrepancy

Enum Discrepancy 

pub enum Discrepancy<'expectation, 'actual> {
    MissingRegion {
        region: &'expectation Region,
    },
    Changed {
        expect: &'expectation [u8],
        actual: &'actual [u8],
        region: &'expectation Region,
    },
}
Embodies a difference of the expectation of the byte buffer and what is actually there

Variants



MissingRegion

The given buffer does not have enough length to be tested

Fields

region: &'expectation Region

The region being tested



Changed

The given buffer did not have the expected byte values

Fields

expect: &'expectation [u8]

Expected byte values

actual: &'actual [u8]

Actual byte values

region: &'expectation Region

The region being tested