pub enum Discrepancy<'expectation, 'actual> {
MissingRegion {
region: &'expectation Region,
},
Changed {
expect: &'expectation [u8],
actual: &'actual [u8],
region: &'expectation Region,
},
}Expand description
Embodies a difference of the expectation of the byte buffer and what is actually there
Variants
MissingRegion
The given buffer does not have enough length to be tested
Changed
The given buffer did not have the expected byte values